# Please do not any airflow imports in this file
# We want to allow importing constants from this file without any side effects

# Do not change this name unless you change the same constant in monitor_as_dag.py in dbnd-airflow-monitor
MONITOR_DAG_NAME = "databand_airflow_monitor"
